@@ -7,10 +7,11 @@ import math
 import numpy as np
 
 
-MAX_SIZE = 2**16
+MAX_SIZE = 2**32
 MAX_DATA_WIDTH = 32
 DEFAULT_DATA_WIDTH = 16
 MAX_CHANNELS = 256
+DATA_TYPE = np.uint32
 
 
 class StreamData():
@@ -20,7 +21,7 @@ class StreamData():
 
     # Define valid ranges for the several StreamData parameters
     PARAMS_RANGE = {
-        "size":       (1, 2**32),
+        "size":       (1, MAX_SIZE),
         "data_width": (1, MAX_DATA_WIDTH),
         "channels":   (1, MAX_CHANNELS)
     }
@@ -153,8 +154,8 @@ class StreamData():
 
     def check_data(self, data, use_data_width=None):
 
-        assert data.dtype == np.int32, \
-            "Data is not np.int32"
+        assert data.dtype == DATA_TYPE, \
+            "Data is not {}".format(DATA_TYPE)
 
         extracted_params = self.extract_params(data, use_data_width)
 
@@ -186,8 +187,8 @@ class StreamData():
 
     def init_with_random(self, seed=None, lower_limit=None, upper_limit=None):
 
-        default_lower_limit = -2**(self.params['data_width']-1)
-        default_upper_limit = 2**(self.params['data_width']-1)-1
+        default_lower_limit = 0
+        default_upper_limit = 2**self.params['data_width']
 
         assert self.params is not None, \
             "Stream parameters needs to be set first!"
@@ -209,7 +210,7 @@ class StreamData():
 
         dim = self.get_np_shape()
 
-        rnd_data = ((upper_limit-lower_limit)*np.random.rand(*dim) + lower_limit).astype(np.int32)
+        rnd_data = ((upper_limit-lower_limit)*np.random.rand(*dim) + lower_limit).astype(DATA_TYPE)
 
         self.init_with_data(rnd_data, False, self.params['data_width'])
 
@@ -232,9 +233,12 @@ class StreamData():
             self.params["size"], self.params["data_width"], self.params["channels"]
         )
 
-        max_value = 2**self.params['data_width'] - 1
+        max_value = 2**self.params['data_width']
         ascii_size = math.floor(math.log(max_value, 10)) + 1
 
+        # VHDL doesn't support uint32 only int32
+        vhdl_data = self.stream_data.astype(np.int32)
+
         with open(path, "w") as txt_file:
             txt_file.write(header)
 
@@ -242,7 +246,7 @@ class StreamData():
             for i in range(self.params['size']):
                 line = ""
                 for channel in range(self.params['channels']):
-                    data_str = str(self.stream_data[i, channel])
+                    data_str = str(vhdl_data[i, channel])
                     line += data_str.rjust(ascii_size, " ") + " "
                 txt_file.write(line + "\n")
             txt_file.close()
@@ -269,7 +273,7 @@ class StreamData():
             ]
 
             stream_params = {"size": 0, "data_width": 8, "channels": 3}
-            stream_data = None
+            vhdl_data = None
             data_coord = [0, 0, 0]
             num_values = 0
             i = 0
@@ -290,7 +294,7 @@ class StreamData():
                     states.remove("HEADER_DATA_WIDTH")
                 elif states[0] == "HEADER_CHANNELS":
                     stream_params["channels"] = int(line)
-                    stream_data = np.zeros(
+                    vhdl_data = np.zeros(
                         (stream_params["size"], stream_params["channels"]), np.int32)
                     num_values = stream_params["size"] * stream_params["channels"]
                     states.remove("HEADER_CHANNELS")
@@ -301,7 +305,7 @@ class StreamData():
                         i += 1
 
                         # pylint: disable=E1137
-                        stream_data[
+                        vhdl_data[
                             data_coord[0],
                             data_coord[1]
                         ] = value
@@ -316,6 +320,7 @@ class StreamData():
         assert i == num_values, \
             "Read Error: Number of pixel does not match header"
 
+        stream_data = vhdl_data.astype(DATA_TYPE)
         self.set_params(stream_params)
         self.init_with_data(
             stream_data[::, 0:stream_params["channels"]],
